@@ -8,7 +8,7 @@ use Audio::PortAudio;
 use List::Util qw( sum );
 use List::MoreUtils qw( none );
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 NAME
 
@@ -28,17 +28,19 @@ Audio::NoiseGen - Unit Generator Based Sound Synthesizer
       release => 0.2,
       gen =>
         combine(
-          segment(notes => '
-            E D C D
-            E E E R
-            D D D R
-            E E E R
-            E D C D
-            E E E/2 E
-            D D E D C
-          '),
-          segment(notes => 'A2 R R R'),
-          segment(notes => 'C3/2 E3/4 E3/4 C3/2 F3 R'),
+          gens => [
+            segment(notes => '
+              E D C D
+              E E E R
+              D D D R
+              E E E R
+              E D C D
+              E E E/2 E
+              D D E D C
+            '),
+            segment(notes => 'A2 R R R'),
+            segment(notes => 'C3/2 E3/4 E3/4 C3/2 F3 R'),
+          ],
         ),
     )
   );
